🔸Chandrayaan-II (DFSAR)
========================


Full-pol (``import_chyaan2_fp``)
--------------------------------

The `import_chyaan2_fp` function extracts matrix elements (S2/C4/T4/C3/T3/C2/T2 ) from the given Chandrayaan-II folder and saves them into respective directories (S2, C3 or T3).

.. autofunction:: polsartools.import_chyaan2_fp
   :noindex:


Compact-pol (``import_chyaan2_cp``)
------------------------------------

The `import_chyaan2_cp` function extracts matrix elements (Sxy, or C2) from the given Chandrayaan-II compact-pol folder and saves them into respective directories.

.. autofunction:: polsartools.import_chyaan2_cp
   :noindex:
